# aliases: hardware

# adafruit_rgb_matrix

```bash
@sbc \
	adafruit_rgb_matrix \
	validate
 . validate adafruit_rgb_matrix.
```

# grove

```bash
grove \
	info
 . show grove info.
grove \
	validate \
	[adc | button]
 . validate grove.
grove \
	validate \
	oled_128x64 \
	[animate | buttons | image | shapes | stats]
 . validate grove oled_128x64.
```

# hat

```bash
@sbc \
	hat \
	input
 . read hat inputs.
@sbc \
	hat \
	output \
	<10101010>
 . activate hat outputs.
@sbc \
	hat \
	validate
 . validate hat.
```

# lepton

```bash
@sbc \
	lepton \
	capture
 . lepton.capture.
@sbc \
	lepton \
	preview
 . lepton.preview.
```

# scroll_phat_hd

```bash
@sbc \
	scroll_phat_hd \
	validate
 . validate scroll_phat_hd.
```

# sparkfun_top_phat

```bash
@sbc \
	sparkfun_top_phat \
	validate \
	[button | leds]
 . validate sparkfun_top_phat.
```

# unicorn_16x16

```bash
@sbc \
	unicorn_16x16 \
	validate
 . validate unicorn_16x16.
```
